@@ -1,6 +1,6 @@
 package Silki::CLI::Import;
 BEGIN {
-  $Silki::CLI::Import::VERSION = '0.18';
+  $Silki::CLI::Import::VERSION = '0.19';
 }
 
 use strict;
@@ -46,21 +46,16 @@ sub _run {
 
     my $wiki;
 
-    eval {
-        my %p = (
-            tarball => $self->tarball(),
-            log     => $self->_log_coderef(),
-            fast    => $self->fast(),
-        );
+    my %p = (
+        tarball => $self->tarball(),
+        log     => $self->_log_coderef(),
+        fast    => $self->fast(),
+    );
 
-        $p{domain}
-            = Silki::Schema::Domain->new( web_hostname => $self->domain() )
-            if $self->domain();
+    $p{domain} = Silki::Schema::Domain->new( web_hostname => $self->domain() )
+        if $self->domain();
 
-        $wiki = Silki::Wiki::Importer->new(%p)->imported_wiki();
-    };
-
-    return $wiki;
+    return Silki::Wiki::Importer->new(%p)->imported_wiki();
 }
 
 sub _final_result_string {
@@ -102,7 +97,7 @@ sub _replace_dbi_manager {
 {
     package _DBIManager;
 BEGIN {
-  $_DBIManager::VERSION = '0.18';
+  $_DBIManager::VERSION = '0.19';
 }
 
     use Moose;
